@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.c,v 1.100 1999/03/23 08:39:57 andrewtv Exp $
+    $Id: util.c,v 1.103 1999/03/25 09:08:32 andrewtv Exp $
 
 ***************************************************************************/
 #include <assert.h>
@@ -2412,13 +2412,14 @@ void IDL_tree_remove_empty_modules (IDL_tree *p, IDL_ns ns)
 	}							\
 } while (0)
 #define save_flag(flagbit,val)	do {				\
-	GPOINTER_TO_UINT (tfd->data) |=				\
-		data->flagbit ? (1UL << flagbit##bit) : 0;	\
+	tfd->data = GUINT_TO_POINTER (				\
+ 		GPOINTER_TO_UINT (tfd->data) |			\
+ 		(data->flagbit ? (1U << flagbit##bit) : 0));	\
 	data->flagbit = val;					\
 } while (0)
-#define restore_flag(flagbit)	do {				\
-	data->flagbit = (GPOINTER_TO_UINT (tfd->data) >> 	\
-			 flagbit##bit) & 1;			\
+#define restore_flag(flagbit)	do {			\
+	data->flagbit = (GPOINTER_TO_UINT (		\
+		tfd->data) >> flagbit##bit) & 1U;	\
 } while (0)
 
 typedef struct {
