@@ -2,23 +2,23 @@
 
     util.h
 
-    Copyright (C) 1998 Andrew T. Veliath
+    Copyright (C) 1998, 1999 Andrew T. Veliath
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
+    This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    You should have received a copy of the GNU Library General Public
+    License along with this library; if not, write to the Free
+    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.h,v 1.33 1998/12/05 19:15:27 andrewtv Exp $
+    $Id: util.h,v 1.39 1999/03/23 08:04:11 andrewtv Exp $
 
 ***************************************************************************/
 #ifndef __UTIL_H
@@ -39,9 +39,9 @@
 #  define alloca
 #endif
 
-/* internal parse flags */
-#define IDLFP_XPIDL_PROPERTY	(1UL << 0)
-#define IDLFP_XPIDL_NATIVE	(1UL << 1)
+/* Internal parse flags */
+#define IDLFP_PROPERTIES	(1UL << 0)
+#define IDLFP_NATIVE		(1UL << 1)
 
 typedef struct {
 	unsigned long flags;
@@ -51,12 +51,18 @@ extern void		yyerror				(const char *s);
 extern void		yyerrorl			(const char *s, int ofs);
 extern void		yywarning			(int level, const char *s);
 extern void		yywarningl			(int level, const char *s, int ofs);
-extern void		yyerrorv			(const char *fmt, ...);
-extern void		yyerrorlv			(const char *fmt, int ofs, ...);
-extern void		yywarningv			(int level, const char *fmt, ...);
-extern void		yywarninglv			(int level, const char *fmt, int ofs, ...);
-extern void		yyerrornv			(IDL_tree p, const char *fmt, ...);
-extern void		yywarningnv			(IDL_tree p, int level, const char *fmt, ...);
+extern void		yyerrorv			(const char *fmt, ...)
+							G_GNUC_PRINTF (1, 2);
+extern void		yyerrorlv			(const char *fmt, int ofs, ...)
+							G_GNUC_PRINTF (1, 3);
+extern void		yywarningv			(int level, const char *fmt, ...)
+							G_GNUC_PRINTF (2, 3);
+extern void		yywarninglv			(int level, const char *fmt, int ofs, ...)
+							G_GNUC_PRINTF (2, 4);
+extern void		yyerrornv			(IDL_tree p, const char *fmt, ...)
+							G_GNUC_PRINTF (2, 3);
+extern void		yywarningnv			(IDL_tree p, int level, const char *fmt, ...)
+							G_GNUC_PRINTF (3, 4);
 
 extern guint		IDL_strcase_hash		(gconstpointer v);
 extern gint		IDL_strcase_equal		(gconstpointer a, gconstpointer b);
@@ -72,6 +78,9 @@ extern void		IDL_tree_remove_inhibits	(IDL_tree *p, IDL_ns ns);
 extern void		IDL_tree_remove_empty_modules	(IDL_tree *p, IDL_ns ns);
 
 extern void		__IDL_free_properties		(GHashTable *table);
+extern void		__IDL_assign_up_node		(IDL_tree up, IDL_tree node);
+extern void		__IDL_assign_location		(IDL_tree node, IDL_tree from_node);
+extern void		__IDL_assign_this_location	(IDL_tree node, char *filename, int line);
 
 #ifndef HAVE_CPP_PIPE_STDIN
 extern char *				__IDL_tmp_filename;
@@ -83,6 +92,7 @@ extern GHashTable *			__IDL_filename_hash;
 extern IDL_fileinfo *			__IDL_cur_fileinfo;
 extern int				__IDL_prev_token_line;
 extern int				__IDL_cur_token_line;
+extern GHashTable *			__IDL_structunion_ht;
 extern int				__IDL_inhibits;
 extern IDL_tree				__IDL_root;
 extern IDL_ns				__IDL_root_ns;
