@@ -19,6 +19,10 @@
 
 #include "orbit-idl.h"
 
+/* IDL node flags so we can apply state info to particular nodes */
+#define IDLFP_MARSHAL_NYI		(1UL << 0)
+#define IDLFP_DEMARSHAL_NYI		(1UL << 1)
+
 void orbit_cbe_write_header(FILE *outfile, IDL_ns ns, IDL_tree tree);
 void orbit_cbe_write_stubs(FILE *outfile, IDL_ns ns, IDL_tree tree,
 			   const char *header_filename);
