@@ -15,6 +15,22 @@ static void cbe_output_marshal_type_typecode(CBEMarshalInfo *mi);
 
 static int loopvarnames = 0;
 
+static void
+cbe_marshal_type_NYI(CBEMarshalInfo *mi)
+{
+  GString *s;
+  IDL_tree p;
+
+  p = IDL_PARAM_DCL(mi->param).param_type_spec;
+  if (p->flags & IDLFP_MARSHAL_NYI)
+	  return;
+  p->flags |= IDLFP_MARSHAL_NYI;
+  s = IDL_tree_to_IDL_string (p, NULL, IDLF_OUTPUT_NO_NEWLINES);
+  IDL_tree_error(p, "Marshalling not yet implemented for `%s'", s->str);
+  g_string_free (s, TRUE);
+  orbit_IDL_compile_failed(FALSE);
+}
+
 void
 cbe_marshaller_align(CBEMarshalInfo *mi)
 {
@@ -66,6 +82,7 @@ void cbe_output_marshaller(CBEMarshalInfo *mi)
     break;
 
   case IDLN_TYPE_OBJECT:
+  case IDLN_FORWARD_DCL:
   case IDLN_INTERFACE:
     cbe_output_marshal_type_object(mi);
     break;
@@ -116,7 +133,7 @@ static void cbe_output_marshal_type_atom(CBEMarshalInfo *mi)
 
 static void cbe_output_marshal_type_fixed(CBEMarshalInfo *mi)
 {
-  g_error("Not yet implemented.");
+  cbe_marshal_type_NYI(mi);
 }
 
 static void cbe_output_marshal_type_string(CBEMarshalInfo *mi)
@@ -248,7 +265,7 @@ static void cbe_output_marshal_type_array(CBEMarshalInfo *mi)
     fprintf(mi->of,
 	    "giop_message_buffer_append_mem(GIOP_MESSAGE_BUFFER(_ORBIT_send_buffer), %s, sizeof(%s));",
 	    mi->param_name, id);
-    free(id);
+    g_free(id);
     mi->previous_param = IDL_TYPE_DCL(dcl).type_spec;
   } else {
     fprintf(mi->of, "  {\n");
