@@ -378,6 +378,10 @@ cbe_tc_generate(CBETCGenInfo *tci)
     break;
   }
 
+  if(!strncmp(tci->structname, "anon", 4)) /* For anonymous typecodes, don't
+					      export the stuff */
+    fprintf(tci->of, "static ");
+
   fprintf(tci->of, "const struct CORBA_TypeCode_struct %s_struct = {\n",
 	  tci->structname);
 
@@ -711,8 +715,4 @@ cbe_tc_generate(CBETCGenInfo *tci)
     fprintf(tci->of, "0, 0");
 
   fprintf(tci->of, "\n};\n");
-#if 0
-  fprintf(tci->of, "const CORBA_TypeCode %s = (const CORBA_TypeCode) &%s_struct;\n",
-	  tci->structname, tci->structname);
-#endif
 }
