@@ -254,6 +254,9 @@ ORBit_marshal_value(GIOPSendBuffer *buf,
 	/* XXX todo */
 	g_error("CORBA_fixed NYI");
 	
+	break;
+    case CORBA_tk_null:
+    case CORBA_tk_void:
 	break;
     default:
 	g_error("Can't encode unknown type %d", tc->kind);
@@ -450,15 +453,18 @@ static gpointer
 ORBit_demarshal_allocate_mem(CORBA_TypeCode tc, gint nelements)
 {
     size_t block_size;
-    gpointer retval;
+    gpointer retval = NULL;
 
     block_size = ORBit_gather_alloc_info(tc);
 
-    retval = ORBit_alloc_2(block_size * nelements,
-			   (ORBit_free_childvals)ORBit_free_via_TypeCode,
-			   GINT_TO_POINTER(nelements), sizeof(CORBA_TypeCode));
+    if(block_size) {
+	retval = ORBit_alloc_2(block_size * nelements,
+			       (ORBit_free_childvals)ORBit_free_via_TypeCode,
+			       GINT_TO_POINTER(nelements),
+			       sizeof(CORBA_TypeCode));
 
-    *(CORBA_TypeCode *)((char *)retval-sizeof(ORBit_mem_info)-sizeof(CORBA_TypeCode)) = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)tc, NULL);
+	*(CORBA_TypeCode *)((char *)retval-sizeof(ORBit_mem_info)-sizeof(CORBA_TypeCode)) = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)tc, NULL);
+    }
 
     return retval;
 }
@@ -851,6 +857,10 @@ _ORBit_copy_value(gpointer *val, gpointer *newval, CORBA_TypeCode tc)
     case CORBA_tk_fixed:
 	g_error("CORBA_fixed NYI!");
 	break;
+    case CORBA_tk_void:
+    case CORBA_tk_null:
+	*val = NULL;
+	break;
     default:
 	g_error("Can't handle copy of value kind %d", tc->kind);
     }
