@@ -59,6 +59,9 @@ CORBA_boolean CORBA_Object_is_nil(CORBA_Object obj, CORBA_Environment *ev)
 }
 
 /* Section 4.2.2 */
+/* XXXX Big warning: lots of places inside ORBit expect this to
+                     always return 'obj'. Do not change this, upon pain
+		     of death... */
 CORBA_Object CORBA_Object_duplicate(CORBA_Object obj, CORBA_Environment *ev)
 {
 	if(obj == CORBA_OBJECT_NIL)
