@@ -3,7 +3,7 @@
 /*
  *  ORBit: A CORBA v2.2 ORB
  *
- *  Copyright (C) 1998 Richard H. Porter
+ *  Copyright (C) 1998 Richard H. Porter, Red Hat Software
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -20,44 +20,370 @@
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Author: Dick Porter <dick@cymru.net>
+ *          Elliot Lee <sopwith@redhat.com>
  *
  */
 
 #include <assert.h>
 
+#include "config.h"
 #include "orbit.h"
+#include "sequences.h"
 
-CORBA_TypeCode *CORBA_DynAny_type(CORBA_DynAny obj, CORBA_Environment *ev)
+#define o_return_if_fail(x)
+#define o_return_val_if_fail(x, y)
+
+static void CORBA_DynAny_release_fn(CORBA_DynAny obj, CORBA_Environment *ev);
+
+static const ORBit_RootObject_Interface CORBA_DynAny__epv = {
+	(void (*)(gpointer, CORBA_Environment *))CORBA_DynAny_release_fn
+};
+
+typedef struct {
+	CORBA_TypeCode tc;
+	union {
+		gpointer sub, sub2;
+		guchar data[sizeof(CORBA_Principal)];
+	} u;
+} dynpiece_t;
+
+static dynpiece_t *
+ORBit_DynAny_items_from_any(CORBA_TypeCode type,
+			    guchar **value,
+			    CORBA_Environment *ev);
+static CORBA_any *ORBit_DynAny_any_from_items(CORBA_DynAny obj,
+					      CORBA_Environment *ev);
+
+/* Operations needed:
+   free what we have
+   copy what we have
+   insert new item
+   delete item
+
+   any -> items
+   items -> any
+ */
+
+/* Section 7.2.2 */
+CORBA_DynAny
+CORBA_ORB_create_dyn_any(CORBA_ORB obj,
+			 CORBA_any *value,
+			 CORBA_Environment *ev)
+{
+	CORBA_DynAny retval;
+	guchar *ptmp;
+
+	g_return_val_if_fail(ev, NULL);
+	o_return_val_if_fail(obj, NULL);
+
+	retval = g_new0(struct CORBA_DynAny_type, 1);
+
+	ORBit_RootObject_set_interface(ORBIT_ROOT_OBJECT(retval),
+				       (ORBit_RootObject_Interface *)&CORBA_DynAny__epv, ev);
+	ORBIT_ROOT_OBJECT(retval)->refs = 0;
+
+	ptmp = value->_value;
+	retval->items =
+		ORBit_DynAny_items_from_any(value->_type, &ptmp, ev);
+
+	return retval;
+}
+
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynAny
+CORBA_ORB_create_basic_dyn_any(CORBA_ORB obj,
+			       CORBA_TypeCode type,
+			       CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
 }
 
-void CORBA_DynAny_assign(CORBA_DynAny obj, CORBA_DynAny dyn_any, CORBA_Environment *ev)
-{
-	g_assert(!"Not yet implemented");
-	return;
-}
-
-void CORBA_DynAny_from_any(CORBA_DynAny obj, CORBA_any value, CORBA_Environment *ev)
-{
-	g_assert(!"Not yet implemented");
-	return;
-}
-
-CORBA_any *CORBA_DynAny_to_any(CORBA_DynAny obj, CORBA_Environment *ev)
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynStruct
+CORBA_ORB_create_dyn_struct(CORBA_ORB obj,
+			    CORBA_TypeCode type,
+			    CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
 }
 
-void CORBA_DynAny_destroy(CORBA_DynAny obj, CORBA_Environment *ev)
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynSequence
+CORBA_ORB_create_dyn_sequence(CORBA_ORB obj,
+			      CORBA_TypeCode type,
+			      CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynArray
+CORBA_ORB_create_dyn_array(CORBA_ORB obj,
+			   CORBA_TypeCode type,
+			   CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynUnion
+CORBA_ORB_create_dyn_union(CORBA_ORB obj,
+			   CORBA_TypeCode type,
+			   CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynEnum
+CORBA_ORB_create_dyn_enum(CORBA_ORB obj,
+			  CORBA_TypeCode type,
+			  CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+/* Section 7.2.2
+ *
+ * raises: InconsistentTypeCode
+ */
+CORBA_DynFixed
+CORBA_ORB_create_dyn_fixed(CORBA_ORB obj,
+			   CORBA_TypeCode type,
+			   CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+static void
+CORBA_DynAny_release_fn(CORBA_DynAny obj, CORBA_Environment *ev)
+{
+	g_free(obj);
+}
+
+CORBA_TypeCode
+CORBA_DynAny_type(CORBA_DynAny obj, CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+static dynpiece_t *
+ORBit_DynAny_items_from_any(CORBA_TypeCode type,
+			    guchar **value,
+			    CORBA_Environment *ev)
+{
+	dynpiece_t *cur, *sub;
+	int i;
+
+	cur = g_new(dynpiece_t, 1);
+	cur->u.sub = NULL;
+	cur->tc = (CORBA_TypeCode)
+		CORBA_Object_duplicate((CORBA_Object)type, ev);
+
+	switch(type->kind) {
+	default:
+		CORBA_Object_release((CORBA_Object)cur->tc, ev);
+		g_free(cur);
+		cur = NULL;
+		break;
+	CORBA_tk_short:
+	CORBA_tk_ushort:
+		memcpy(cur->u.data, *value, sizeof(CORBA_short));
+		*value += sizeof(CORBA_short);
+		break;
+	CORBA_tk_long:
+	CORBA_tk_ulong:
+	CORBA_tk_enum:
+		memcpy(cur->u.data, *value, sizeof(CORBA_long));
+		*value += sizeof(CORBA_long);
+		break;
+	CORBA_tk_float:
+		memcpy(cur->u.data, *value, sizeof(CORBA_float));
+		*value += sizeof(CORBA_float);
+		break;
+	CORBA_tk_double:
+		memcpy(cur->u.data, *value, sizeof(CORBA_double));
+		*value += sizeof(CORBA_double);
+		break;
+	CORBA_tk_boolean:
+	CORBA_tk_char:
+	CORBA_tk_octet:
+		memcpy(cur->u.data, *value, sizeof(CORBA_octet));
+		*value += sizeof(CORBA_octet);
+		break;
+	CORBA_tk_any:
+		{
+			CORBA_any *anyval;
+			gpointer ptmp;
+
+			anyval = (CORBA_any *)*value;
+			ptmp = anyval->_value;
+			cur->u.sub = ORBit_DynAny_items_from_any(anyval->_type,
+								 ptmp,
+								 ev);
+			*value += sizeof(CORBA_any);
+		}
+		break;
+	CORBA_tk_TypeCode:
+	CORBA_tk_objref:
+		memcpy(cur->u.data, *value, sizeof(CORBA_Object));
+		CORBA_Object_duplicate((CORBA_Object)cur->u.data, ev);
+		*value += sizeof(CORBA_Object);
+		break;
+	CORBA_tk_Principal:
+		{
+			/* aka sequence_octet, oh well */
+			CORBA_Principal *prtmp;
+
+			memcpy(cur->u.data, *value, sizeof(CORBA_Principal));
+			prtmp = (CORBA_Principal *)cur->u.data;
+			prtmp->_buffer =
+				CORBA_octet_allocbuf(prtmp->_length);
+
+			memcpy(prtmp->_buffer, 
+			       ((CORBA_Principal *)*value)->_buffer,
+			       prtmp->_length);
+			*value += sizeof(CORBA_Principal);
+		}
+		break;
+ 	CORBA_tk_struct:
+		*value = ALIGN_ADDRESS(*value, ALIGNOF_CORBA_STRUCT);
+		for(i = 0; i < type->sub_parts; i++) {
+			*value = ALIGN_ADDRESS(*value,
+					       ORBit_find_alignment(type->subtypes[i]));
+			sub = ORBit_DynAny_items_from_any(type->subtypes[i],
+							  value,
+							  ev);
+							  
+			cur->u.sub = g_list_append(cur->u.sub,
+						   sub);
+		}
+		break;
+	CORBA_tk_union:
+		{
+			CORBA_TypeCode data_tc;
+
+			*value = ALIGN_ADDRESS(*value,
+					       MAX(ALIGNOF_CORBA_STRUCT,
+						   ORBit_find_alignment(type->discriminator)));
+
+			cur->u.sub =
+				ORBit_DynAny_items_from_any(type->discriminator,
+							    value, ev);
+
+			data_tc = ORBit_get_union_tag(type, *value);
+
+			*value = ALIGN_ADDRESS(*value,
+					       ORBit_find_alignment(data_tc));
+			cur->u.sub2 = 
+				ORBit_DynAny_items_from_any(data_tc,
+							    value, ev);
+		}
+		break;
+	CORBA_tk_string:
+		cur->u.sub = CORBA_string_dup(*(CORBA_char **)*value);
+		*value += sizeof(CORBA_char *);
+		break;
+	CORBA_tk_sequence:
+#ifdef FINISH_OFF_HERE_YOU_MORON
+		for(i = 0; i < 
+		cur->u.sub
+#endif
+		break;
+	CORBA_tk_array:
+		break;
+	CORBA_tk_alias:
+		break;
+	CORBA_tk_except:
+		break;
+	CORBA_tk_longlong:
+		break;
+	CORBA_tk_ulonglong:
+		break;
+	CORBA_tk_longdouble:
+		break;
+	CORBA_tk_wchar:
+		break;
+	CORBA_tk_wstring:
+		break;
+	CORBA_tk_fixed:
+		break;
+	CORBA_tk_recursive:
+		break;
+	}
+
+	return cur;
+}
+
+static CORBA_any *
+ORBit_DynAny_any_from_items(CORBA_DynAny obj,
+			    CORBA_Environment *ev)
+{
+	return NULL;
+}
+
+void
+CORBA_DynAny_assign(CORBA_DynAny obj,
+		    CORBA_DynAny dyn_any,
+		    CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return;
 }
 
-CORBA_DynAny *CORBA_DynAny_copy(CORBA_DynAny obj, CORBA_Environment *ev)
+void
+CORBA_DynAny_from_any(CORBA_DynAny obj,
+		      CORBA_any value, CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return;
+}
+
+CORBA_any *
+CORBA_DynAny_to_any(CORBA_DynAny obj,
+		    CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return(NULL);
+}
+
+void
+CORBA_DynAny_destroy(CORBA_DynAny obj,
+		     CORBA_Environment *ev)
+{
+	g_assert(!"Not yet implemented");
+	return;
+}
+
+CORBA_DynAny
+CORBA_DynAny_copy(CORBA_DynAny obj,
+		  CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -241,7 +567,9 @@ CORBA_Object CORBA_DynAny_get_reference(CORBA_DynAny obj, CORBA_Environment *ev)
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynAny_get_typecode(CORBA_DynAny obj, CORBA_Environment *ev)
+CORBA_TypeCode
+CORBA_DynAny_get_typecode(CORBA_DynAny obj,
+			  CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -286,7 +614,9 @@ CORBA_any *CORBA_DynAny_get_any(CORBA_DynAny obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynAny_current_component(CORBA_DynAny obj, CORBA_Environment *ev)
+CORBA_DynAny
+CORBA_DynAny_current_component(CORBA_DynAny obj,
+			       CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -324,7 +654,8 @@ void CORBA_DynFixed_set_value(CORBA_DynFixed obj, CORBA_DynFixed_OctetSeq *val,
 }
 
 
-CORBA_TypeCode *CORBA_DynFixed_type(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_TypeCode
+CORBA_DynFixed_type(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -354,7 +685,8 @@ void CORBA_DynFixed_destroy(CORBA_DynFixed obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynFixed_copy(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_DynAny
+CORBA_DynFixed_copy(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -532,13 +864,15 @@ CORBA_char *CORBA_DynFixed_get_string(CORBA_DynFixed obj, CORBA_Environment *ev)
 	return(NULL);
 }
 
-CORBA_Object CORBA_DynFixed_get_reference(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_Object
+CORBA_DynFixed_get_reference(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynFixed_get_typecode(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_TypeCode
+CORBA_DynFixed_get_typecode(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -576,14 +910,17 @@ CORBA_wchar *CORBA_DynFixed_get_wstring(CORBA_DynFixed obj, CORBA_Environment *e
 	return(NULL);
 }
 
-CORBA_any *CORBA_DynFixed_get_any(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_any *
+CORBA_DynFixed_get_any(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
+
 	return(NULL);
 }
 
 
-CORBA_DynAny *CORBA_DynFixed_current_component(CORBA_DynFixed obj, CORBA_Environment *ev)
+CORBA_DynAny
+CORBA_DynFixed_current_component(CORBA_DynFixed obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -633,7 +970,8 @@ void CORBA_DynEnum__set_value_as_ulong(CORBA_DynEnum obj, CORBA_unsigned_long va
 }
 
 
-CORBA_TypeCode *CORBA_DynEnum_type(CORBA_DynEnum obj, CORBA_Environment *ev)
+CORBA_TypeCode
+CORBA_DynEnum_type(CORBA_DynEnum obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -663,7 +1001,8 @@ void CORBA_DynEnum_destroy(CORBA_DynEnum obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynEnum_copy(CORBA_DynEnum obj, CORBA_Environment *ev)
+CORBA_DynAny
+CORBA_DynEnum_copy(CORBA_DynEnum obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -847,7 +1186,7 @@ CORBA_Object CORBA_DynEnum_get_reference(CORBA_DynEnum obj, CORBA_Environment *e
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynEnum_get_typecode(CORBA_DynEnum obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynEnum_get_typecode(CORBA_DynEnum obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -892,7 +1231,8 @@ CORBA_any *CORBA_DynEnum_get_any(CORBA_DynEnum obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynEnum_current_component(CORBA_DynEnum obj, CORBA_Environment *ev)
+CORBA_DynAny
+CORBA_DynEnum_current_component(CORBA_DynEnum obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -944,7 +1284,7 @@ void CORBA_DynStruct_set_members(CORBA_DynStruct obj, CORBA_NameValuePairSeq *va
 }
 
 
-CORBA_TypeCode *CORBA_DynStruct_type(CORBA_DynStruct obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynStruct_type(CORBA_DynStruct obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -974,7 +1314,7 @@ void CORBA_DynStruct_destroy(CORBA_DynStruct obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynStruct_copy(CORBA_DynStruct obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynStruct_copy(CORBA_DynStruct obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1158,7 +1498,7 @@ CORBA_Object CORBA_DynStruct_get_reference(CORBA_DynStruct obj, CORBA_Environmen
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynStruct_get_typecode(CORBA_DynStruct obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynStruct_get_typecode(CORBA_DynStruct obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1203,7 +1543,7 @@ CORBA_any *CORBA_DynStruct_get_any(CORBA_DynStruct obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynStruct_current_component(CORBA_DynStruct obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynStruct_current_component(CORBA_DynStruct obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1228,7 +1568,7 @@ void CORBA_DynStruct_rewind(CORBA_DynStruct obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynUnion_discriminator(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynUnion_discriminator(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1242,7 +1582,7 @@ CORBA_TCKind CORBA_DynUnion_discriminator_kind(CORBA_DynUnion obj, CORBA_Environ
 	return(ret);
 }
 
-CORBA_DynAny *CORBA_DynUnion_member(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynUnion_member(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1281,7 +1621,7 @@ void CORBA_DynUnion__set_member_name(CORBA_DynUnion obj, CORBA_FieldName member_
 }
 
 
-CORBA_TypeCode *CORBA_DynUnion_type(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynUnion_type(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1311,7 +1651,7 @@ void CORBA_DynUnion_destroy(CORBA_DynUnion obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynUnion_copy(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynUnion_copy(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1495,7 +1835,7 @@ CORBA_Object CORBA_DynUnion_get_reference(CORBA_DynUnion obj, CORBA_Environment
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynUnion_get_typecode(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynUnion_get_typecode(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1540,7 +1880,7 @@ CORBA_any *CORBA_DynUnion_get_any(CORBA_DynUnion obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynUnion_current_component(CORBA_DynUnion obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynUnion_current_component(CORBA_DynUnion obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1590,7 +1930,7 @@ void CORBA_DynSequence__set_length(CORBA_DynSequence obj, CORBA_unsigned_long le
 }
 
 
-CORBA_TypeCode *CORBA_DynSequence_type(CORBA_DynSequence obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynSequence_type(CORBA_DynSequence obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1620,7 +1960,7 @@ void CORBA_DynSequence_destroy(CORBA_DynSequence obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynSequence_copy(CORBA_DynSequence obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynSequence_copy(CORBA_DynSequence obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1804,7 +2144,7 @@ CORBA_Object CORBA_DynSequence_get_reference(CORBA_DynSequence obj, CORBA_Enviro
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynSequence_get_typecode(CORBA_DynSequence obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynSequence_get_typecode(CORBA_DynSequence obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1849,7 +2189,7 @@ CORBA_any *CORBA_DynSequence_get_any(CORBA_DynSequence obj, CORBA_Environment *e
 }
 
 
-CORBA_DynAny *CORBA_DynSequence_current_component(CORBA_DynSequence obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynSequence_current_component(CORBA_DynSequence obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1887,7 +2227,7 @@ void CORBA_DynArray_set_elements(CORBA_DynArray obj, CORBA_AnySeq *value, CORBA_
 }
 
 
-CORBA_TypeCode *CORBA_DynArray_type(CORBA_DynArray obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynArray_type(CORBA_DynArray obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -1917,7 +2257,7 @@ void CORBA_DynArray_destroy(CORBA_DynArray obj, CORBA_Environment *ev)
 	return;
 }
 
-CORBA_DynAny *CORBA_DynArray_copy(CORBA_DynArray obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynArray_copy(CORBA_DynArray obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -2101,7 +2441,7 @@ CORBA_Object CORBA_DynArray_get_reference(CORBA_DynArray obj, CORBA_Environment
 	return(NULL);
 }
 
-CORBA_TypeCode *CORBA_DynArray_get_typecode(CORBA_DynArray obj, CORBA_Environment *ev)
+CORBA_TypeCode CORBA_DynArray_get_typecode(CORBA_DynArray obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
@@ -2146,7 +2486,7 @@ CORBA_any *CORBA_DynArray_get_any(CORBA_DynArray obj, CORBA_Environment *ev)
 }
 
 
-CORBA_DynAny *CORBA_DynArray_current_component(CORBA_DynArray obj, CORBA_Environment *ev)
+CORBA_DynAny CORBA_DynArray_current_component(CORBA_DynArray obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(NULL);
