@@ -32,6 +32,8 @@
 #define _ORBIT_ORBIT_POA_H_
 
 #include "orbit_types.h"
+#include "orbit_poa_type.h"
+
 
 /*
  * Creates a new POAManager
@@ -65,7 +67,7 @@ ORBit_POA_find_POA_for_object_key(PortableServer_POA root_poa,
 				  CORBA_sequence_octet *key);
 void
 ORBit_POA_find_object_key_for_oid(PortableServer_POA poa,
-				  PortableServer_ObjectId *oid,
+				  ORBit_POAObject *obj,
 				  CORBA_sequence_octet *retval);
 
 PortableServer_ObjectId *ORBit_POA_allocate_oid(PortableServer_POA poa,
