@@ -52,6 +52,7 @@ ORBit_handle_incoming_request(GIOPRecvBuffer *recv_buffer)
 	CORBA_ORB orb;
 	PortableServer_POA poa;
 	GIOPConnection *connection;
+	ORBit_MessageValidationResult mvr;
 
 	g_assert(recv_buffer!=NULL);
 
@@ -67,10 +68,18 @@ ORBit_handle_incoming_request(GIOPRecvBuffer *recv_buffer)
 		    recv_buffer->message.u.request.operation,
 		    recv_buffer->message.u.request.request_id,
 		    recv_buffer->message.u.request.object_key._buffer);
-	if(!request_validator
-	   || request_validator(recv_buffer->message.u.request.request_id,
+
+	if(request_validator)
+		mvr = request_validator(recv_buffer->message.u.request.request_id,
 				&recv_buffer->message.u.request.requesting_principal,
-				recv_buffer->message.u.request.operation)) {
+				recv_buffer->message.u.request.operation);
+	else
+		mvr = ORBIT_MESSAGE_ALLOW;
+
+	if(mvr == ORBIT_MESSAGE_ALLOW_ALL)
+		connection->is_auth = TRUE;
+
+	if(mvr != ORBIT_MESSAGE_BAD) {
 		/* Find the POA for this incoming request */
 		poa = ORBit_find_POA_for_request((PortableServer_POA)orb->root_poa,
 						 recv_buffer);
@@ -153,11 +162,8 @@ ORBit_handle_incoming_message(GIOPRecvBuffer *recv_buffer)
 	case GIOP_CLOSECONNECTION:
 		/* Lame hack - need to do this in a manner that isn't
                    IIOP-specific */
-		shutdown(IIOP_CONNECTION(connection)->fd, 2);
-		close(IIOP_CONNECTION(connection)->fd);
-		IIOP_CONNECTION(connection)->fd = -1;
-		giop_connection_unref(connection);
 		giop_recv_buffer_unuse(recv_buffer);
+		giop_main_handle_connection_exception(connection);
 		break;
 	default:
 		g_warning("discarding message type %d (id possibly %d)",
